# RoboSSlyze

Robot Framework Library for python's SSLyze Script

## Installation

`pip install RoboSslyze`


## Running RoboSslyze

### Keywords

#### Basic SSL/TLS Test

`| test ssl basic  | host  (ip/domain)  | port (optional |`

Tests the following:

* SSLv2 Cipher Suites
* SSLv3 Cipher Suites
* TLSv1 Cipher Suites
* TLSv11 Cipher Suites
* TLSv12 Cipher Suites
* Heartbleed check
* ROBOT Vulnerability Check

#### HTTP SSL/TLS Headers Check

`| test ssl server headers  | host (ip/domain)  | port (optional)`

**this only works with HTTP services**

Tests for the following:

* HSTS Headers
* Expect-CT Header

All Results are printed to the `log.html` file generated by Robot

### Example

```
*** Settings ***
Library  RoboSslyze

*** Variables ***
${TARGET}  www.google.com

*** Test Cases ***
Test for SSL
    test ssl basic  ${TARGET}
    test ssl server headers  ${TARGET}

```



